==> pointpos_api-0.0.16.tar.gz: test/item_api_test.dart <==
import 'package:pointpos_api/api.dart';
import 'package:test/test.dart';


/// tests for ItemApi
void main() {
  var instance = new ItemApi();

  group('tests for ItemApi', () {
    // Create Item
    //
    // Create Item
    //
    //Future<Item> createItem(String authorization, String xAPIKey, Item body, { String xPin }) async 
    test('test createItem', () async {
      // TODO
    });

    // Create Item Image
    //
    // Create Item Image
    //
    //Future<Item> createItemImage(String authorization, String xAPIKey, String id, MultipartFile file, bool isMain, { String xPin }) async 
    test('test createItemImage', () async {
      // TODO
    });

    // Delete Item By ID
    //
    // Delete Item By ID
    //
    //Future deleteItemByID(String authorization, String xAPIKey, String id, { String xPin }) async 
    test('test deleteItemByID', () async {
      // TODO
    });

    // Delete Item Image By ID
    //
    // Delete Item Image By ID
    //
    //Future deleteItemImageByID(String authorization, String xAPIKey, String id, String imageId, { String xPin }) async 
    test('test deleteItemImageByID', () async {
      // TODO
    });

    // Get Item List
    //
    // Get Item  List
    //
    //Future<List<Item>> findItem(String authorization, String xAPIKey, { String xPin, num limit, num offset, String sort, String direction, List<String> filter }) async 
    test('test findItem', () async {
      // TODO
    });

    // Get Item By ID
    //
    // Get Item By ID
    //
    //Future<Item> getItemByID(String authorization, String xAPIKey, String id, { String xPin }) async 
    test('test getItemByID', () async {
      // TODO
    });

    // Update Item By ID
    //
    // Update [object Object] By ID
    //
    //Future<Item> updateItemByID(String authorization, String xAPIKey, String id, Item body, { String xPin }) async 
    test('test updateItemByID', () async {
      // TODO
    });

    // Update Item Image By ID
    //
    // Update Item Image By ID
    //
    //Future<Item> updateItemImageByID(String authorization, String xAPIKey, String id, String imageId, { String xPin, MultipartFile file, bool isMain }) async 
    test('test updateItemImageByID', () async {
      // TODO
    });

  });
}

==> pointpos_api-0.2.0.tar.gz: test/item_api_test.dart <==
import 'package:pointpos_api/api.dart';
import 'package:test/test.dart';


/// tests for ItemApi
void main() {
  var instance = new ItemApi();

  group('tests for ItemApi', () {
    // Create Item
    //
    // Create Item
    //
    //Future<Item> createItem(String authorization, String xAPIKey, Item body, { String xPin }) async 
    test('test createItem', () async {
      // TODO
    });

    // Create Item Image
    //
    // Create Item Image
    //
    //Future<Item> createItemImage(String authorization, String xAPIKey, String id, MultipartFile file, bool isMain, { String xPin }) async 
    test('test createItemImage', () async {
      // TODO
    });

    // Delete Item By ID
    //
    // Delete Item By ID
    //
    //Future deleteItemByID(String authorization, String xAPIKey, String id, { String xPin }) async 
    test('test deleteItemByID', () async {
      // TODO
    });

    // Delete Item Image By ID
    //
    // Delete Item Image By ID
    //
    //Future deleteItemImageByID(String authorization, String xAPIKey, String id, String imageId, { String xPin }) async 
    test('test deleteItemImageByID', () async {
      // TODO
    });

    // Get Item List
    //
    // Get Item  List
    //
    //Future<List<Item>> findItem(String authorization, String xAPIKey, { String xPin, num limit, num offset, String sort, String direction, List<String> filter, bool withDeleted }) async 
    test('test findItem', () async {
      // TODO
    });

    // Get Item By ID
    //
    // Get Item By ID
    //
    //Future<Item> getItemByID(String authorization, String xAPIKey, String id, { String xPin }) async 
    test('test getItemByID', () async {
      // TODO
    });

    // Update Item By ID
    //
    // Update [object Object] By ID
    //
    //Future<Item> updateItemByID(String authorization, String xAPIKey, String id, Item body, { String xPin }) async 
    test('test updateItemByID', () async {
      // TODO
    });

    // Update Item Image By ID
    //
    // Update Item Image By ID
    //
    //Future<Item> updateItemImageByID(String authorization, String xAPIKey, String id, String imageId, { String xPin, MultipartFile file, bool isMain }) async 
    test('test updateItemImageByID', () async {
      // TODO
    });

  });
}
